# -#- coding: utf-8 -#-

from django.db import models
from django.utils.translation import ugettext_lazy as _
from leonardo.module.web.models import Widget
from leonardo_module_links.models import Link

SIZE_CHOICES = (
    ('normal', _('normal')),
    ('large', _('large')),
)

PRIORITY_CHOICES = (
    ('primary', _('primary')),
    ('secondary', _('secondary')),
)

ALIGN_CHOICES = (
    ('left', _('left')),
    ('right', _('right')),
)

ON_CLICK_CHOICES = (
    ('go_to_page', _('go to linked page')),
    ('open_modal', _('open in modal window')),
    ('open_tab', _('open in new window/tab')),
)

class LinkButtonWidget(Widget):
    link = models.ForeignKey(Link, verbose_name=_("link"), blank=True, null=True, related_name="%(app_label)s_%(class)s_related")
    alt_link = models.CharField(max_length=255, verbose_name=_("alt. link"), blank=True, help_text=_("You can use relative or absolute URLs."))
    text = models.CharField(max_length=255, verbose_name=_("text"), blank=True)
    size = models.CharField(max_length=255, verbose_name=_("size"), choices=SIZE_CHOICES, default="normal")
    priority = models.CharField(max_length=255, verbose_name=_("priority"), choices=PRIORITY_CHOICES, default="primary")
    alignment = models.CharField(max_length=255, verbose_name=_("alignment"), choices=ALIGN_CHOICES, default='left')
    on_click = models.CharField(max_length=255, verbose_name=_("on click action"), choices=ON_CLICK_CHOICES, default='go_to_page')

    class Meta:
        abstract = True
        verbose_name = _("link button")
        verbose_name_plural = _('link buttons')



# -#- coding: utf-8 -#-

from django.db import models
from django.utils.translation import ugettext_lazy as _

from leonardo.module.web.models import Widget

from leonardo_module_links.models import LinkCategory, Link


class LinkMenuWidget(Widget):
    list = models.ForeignKey(LinkCategory, verbose_name=_("link category"), related_name="%(app_label)s_%(class)s_related")

    def get_links(self):
        return Link.objects.filter(category=self.list, visible=True).order_by('ordering')

    class Meta:
        abstract = True
        verbose_name = _("links menu")
        verbose_name_plural = _('links menus')




from django.contrib import admin
from django.conf import settings

from .models import Link, LinkCategory, LinkTranslation


class LinkTranslation_Inline(admin.TabularInline):
    model = LinkTranslation
    max_num = len(settings.LANGUAGES)


class Link_Inline(admin.TabularInline):
    model = Link


class LinkAdmin(admin.ModelAdmin):
    list_display = ['__unicode__', 'web_address', 'category', 'ordering', 'visible']
    list_filter = ['category']
    list_per_page = 50
    inlines = [LinkTranslation_Inline, ]
    search_fields = ['name', 'description']


class LinkCategoryAdmin(admin.ModelAdmin):
    list_display = ['name', 'slug', 'description']
    inlines = [Link_Inline, ]

admin.site.register(Link, LinkAdmin)
admin.site.register(LinkCategory, LinkCategoryAdmin)



# -#- coding: utf-8 -#-

from django.db import models
from django.utils.translation import ugettext_lazy as _
from feincms.translations import (TranslatedObjectManager,
                                  TranslatedObjectMixin, Translation)
from leonardo.module.media.models import Image


class LinkCategory(models.Model):
    name = models.CharField(max_length=255, verbose_name=_("name"))
    slug = models.CharField(max_length=255, verbose_name=_("slug"), blank=True)
    description = models.TextField(blank=True, verbose_name=_("description"))

    def __unicode__(self):
        return u'%s' % self.name

    class Meta:
        verbose_name = _('link category')
        verbose_name_plural = _('link categories')


TARGET_CHOICES = (
    ('_none', _('same window')),
    ('_modal', _('modal window')),
    ('_blank', _('new tab')),
)


class Link(models.Model, TranslatedObjectMixin):
    web_address = models.CharField(
        max_length=255, verbose_name=_("web address"))
    target = models.CharField(max_length=255, verbose_name=_(
        "target"), choices=TARGET_CHOICES, default='_none')
    relationship = models.ForeignKey('self',
                                     blank=True, null=True, verbose_name=_("link relationship"))
    image = models.ForeignKey(
        Image, blank=True, null=True, verbose_name=_("image"))
    category = models.ForeignKey(LinkCategory, verbose_name=_("link category"))
    visible = models.BooleanField(verbose_name=_("visible"), default=True)
    ordering = models.PositiveIntegerField(
        verbose_name=_("ordering"), default=0)

    objects = TranslatedObjectManager()

    def __unicode__(self):
        trans = None

        # This might be provided using a .extra() clause to avoid hundreds of
        # extra queries:
        if hasattr(self, "preferred_translation"):
            trans = getattr(self, "preferred_translation", u"")
        else:
            try:
                trans = unicode(self.translation)
            except models.ObjectDoesNotExist:
                pass
            except AttributeError:
                pass

        if trans:
            return trans
        else:
            return self.web_address

    class Meta:
        ordering = ['ordering', ]
        verbose_name = _('link')
        verbose_name_plural = _('links')


class LinkTranslation(Translation(Link)):

    """
    Translated link name and description.
    """

    name = models.CharField(_('name'), max_length=200)
    description = models.TextField(_('description'), blank=True)

    class Meta:
        verbose_name = _('link translation')
        verbose_name_plural = _('link translations')

    def __unicode__(self):
        return self.name




from django.apps import AppConfig

from .widget import *


default_app_config = 'leonardo_module_links.LinksConfig'


class Default(object):

    optgroup = ('Links')

    apps = [
            'leonardo_module_links',
        ]

    @property
    def widgets(self):
        return [
            LinkButtonWidget,
            LinkMenuWidget,
        ]


class LinksConfig(AppConfig, Default):
    name = 'leonardo_module_links'
    verbose_name = "Links Widgets"

default = Default()
